@@ -46,7 +46,7 @@ def parse_spec(spec: dict[str, Any]) -> KeySpecification:
     """Parse the specification of a *key* using the parameters defined by the
     specification `spec`.
     """
-    p = provider(spec.pop('provider'))
+    p = provider(spec.get('provider'))
     return p.parse_spec(spec)
 
 
