@@ -18,6 +18,7 @@ import pydantic
 from typing_extensions import Annotated
 
 from ckms.core import models
+from ckms.types import Algorithm
 from .types import EdwardsCurveKeySpecification
 from .types import EllipticCurveKeySpecification
 from .types import RSAKeySpecification
@@ -39,4 +40,16 @@ class KeySpecification(models.BaseKeySpecification):
 
     @classmethod
     def parse_obj(cls: type[pydantic.BaseModel], obj: Any) -> models.KeySpecification:
-        return super().parse_obj(obj).__root__ # type: ignore
\ No newline at end of file
+        return super().parse_obj(obj).__root__ # type: ignore
+
+    @pydantic.root_validator(pre=True)
+    def preprocess(cls, values: dict[str, Any]) -> dict[str, Any]:
+        spec: dict[str, Any] = values.get('__root__', {})
+        alg: str | None | Algorithm = spec.get('alg') or spec.get('algorithm')
+        if alg is not None:
+            alg = Algorithm.get(alg)
+            spec.update({
+                'kty': alg.kty
+            })
+
+        return values
\ No newline at end of file
