@@ -24,8 +24,13 @@ from .localkeyspecification import LocalKeySpecification
 class LocalKey(pydantic.BaseModel):
     path: str | pathlib.Path
     password: bytes | None
-    encoding: Literal['pem'] = 'pem'
+    encoding: Literal['binary', 'pem'] = 'pem'
 
     async def setup(self, spec: LocalKeySpecification) -> Any:
+        if self.encoding not in ('binary', 'pem'):
+            raise NotImplementedError(self.encoding)
+        decode: Any = lambda x, *a, **k: x # type: ignore
+        if self.encoding == 'pem':
+            decode = load_pem_private_key
         with open(self.path, 'rb') as f:
-            return load_pem_private_key(f.read(), self.password)
\ No newline at end of file
+            return decode(f.read(), self.password)
\ No newline at end of file
