@@ -76,8 +76,8 @@ class Encoder:
         the default content type, for example when encoding an :rfc:`RFC9068`
         access token which uses ``at+jwt`` as its content type.
         """
-        encrypters = encrypters or []
-        must_encrypt = encrypt or bool(encrypters)
+        encrypters = encrypters or self.encryption_keys
+        must_encrypt = encrypt and bool(encrypters)
         must_sign = sign or bool(signing_keys) or bool(signers)
         signers = signers or signing_keys or self.signing_keys
         if isinstance(content, str):
